@@ -353,7 +353,7 @@ static void process_options(int argc, char *argv[], unsigned int max_cpus)
 	}
 }
 
-static void sighand(int sig __attribute__ ((unused)))
+static void sighand(int sig)
 {
 	shutdown = 1;
 }
